@@ -9,12 +9,14 @@ pub mod canvas;
 pub mod data;
 pub mod event;
 pub mod texture;
+pub mod color;
 
 pub use canvas::Canvas;
 pub use canvas::DrawDestination;
 pub use canvas::Screen;
 pub use event::Event;
 pub use texture::Texture;
+pub use color::Rgba;
 
 /// Just represents the unit for euclidean transforms.
 #[derive(Clone, Copy, Debug, Default, PartialEq, Eq, PartialOrd, Ord, Hash)]
@@ -34,43 +36,6 @@ pub type Rect = euclid::Rect<GridUnit, Pixels>;
 pub type Size = euclid::Size2D<GridUnit, Pixels>;
 pub type Point = euclid::Point2D<GridUnit, Pixels>;
 
-#[derive(Default, Clone, Copy, Hash, Debug, Eq, PartialEq, Ord, PartialOrd)]
-pub struct Rgba {
-    pub r: u8,
-    pub g: u8,
-    pub b: u8,
-    pub a: u8,
-}
-
-impl Rgba {
-    pub fn white() -> Rgba {
-        Rgba {
-            r: u8::MAX,
-            g: u8::MAX,
-            b: u8::MAX,
-            a: u8::MAX,
-        }
-    }
-
-    pub fn black() -> Rgba {
-        Rgba {
-            r: u8::MIN,
-            g: u8::MIN,
-            b: u8::MIN,
-            a: u8::MAX,
-        }
-    }
-
-    pub fn clear() -> Rgba {
-        Rgba {
-            r: u8::MIN,
-            g: u8::MIN,
-            b: u8::MIN,
-            a: u8::MIN,
-        }
-    }
-}
-
 pub trait Game {
     /// Create a new Game of this type, starting at the given time in seconds.
     fn new(timestamp: f64) -> Self;
